@@ -14,8 +14,8 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
-## @deftypefn {Function File} {} bitunpack (@var{X})
+## @documentencoding UTF-8
+## @defmethod {@@infsup} bitunpack (@var{X})
 ## @comment DO NOT SYNCHRONIZE DOCUMENTATION STRING
 ## 
 ## Encode bare interval @var{X} in interchange format.
@@ -30,7 +30,7 @@
 ## @code{@var{X} == interval_bitpack (bitunpack (@var{X}))}.
 ##
 ## @seealso{interval_bitpack}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
