@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} cos (@var{X})
+## @defmethod {@@infsup} cos (@var{X})
 ## 
 ## Compute the cosine in radians.
 ##
@@ -24,11 +24,11 @@
 ## @example
 ## @group
 ## cos (infsup (1))
-##   @result{} ans ⊂ [0.5403023058681396, 0.5403023058681398]
+##   @result{} ans ⊂ [0.5403, 0.54031]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/acos, @@infsup/sec, @@infsup/cosh}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
