@@ -15,8 +15,8 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} dot (@var{X}, @var{Y})
-## @deftypefnx {Function File} {} dot (@var{X}, @var{Y}, @var{DIM})
+## @defmethod {@@infsup} dot (@var{X}, @var{Y})
+## @defmethodx {@@infsup} dot (@var{X}, @var{Y}, @var{DIM})
 ## 
 ## Compute the dot product of two interval vectors.
 ## 
@@ -33,11 +33,11 @@
 ## @end group
 ## @group
 ## dot (infsup ([realmax; realmin; realmax]), [1; -1; -1], 1)
-##   @result{} ans ⊂ [-2.2250738585072014e-308, -2.2250738585072013e-308]
+##   @result{} ans ⊂ [-2.2251e-308, -2.225e-308]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/plus, @@infsup/sum, @@infsup/times, @@infsup/sumabs, @@infsup/sumsq}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
