@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} ei (@var{X})
+## @defmethod {@@infsup} ei (@var{X})
 ## 
 ## Compute the exponential integral for positive arguments.
 ##
@@ -41,10 +41,10 @@
 ## @example
 ## @group
 ## ei (infsup (1))
-##   @result{} ans ⊂ [1.8951178163559365, 1.8951178163559368]
+##   @result{} ans ⊂ [1.8951, 1.8952]
 ## @end group
 ## @end example
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
