@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} {@var{x} =} gauss (@var{A}, @var{b})
+## @deftypemethod {@@infsup} {@var{x} =} gauss (@var{A}, @var{b})
 ## 
 ## Solve a linear interval system @var{A} * @var{x} = @var{b} using Gaussian
 ## elimination.
@@ -32,14 +32,13 @@
 ## @example
 ## @group
 ## gauss (infsup ([1, 0; 0, 2]), [2, 0; 0, 4])
-##   @result{} 2×2 interval matrix
-##
+##   @result{} ans = 2×2 interval matrix
 ##      [2]   [0]
 ##      [0]   [2]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/mldivide}
-## @end deftypefn
+## @end deftypemethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
