@@ -14,15 +14,16 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
-## @deftypefn {Function File} {} {} @var{A} >= @var{B}
+## @documentencoding UTF-8
+## @defop Method {@@infsup} ge (@var{A}, @var{B})
+## @defopx Operator {@@infsup} {@var{A} >= @var{B}}
 ## 
 ## Compare intervals @var{A} and @var{B} for weakly greater.
 ##
 ## Evaluated on interval matrices, this functions is applied element-wise.
 ##
 ## @seealso{@@infsup/eq, @@infsup/le, @@infsup/gt}
-## @end deftypefn
+## @end defop
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
