@@ -14,8 +14,8 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
-## @deftypefn {Function File} {} interior (@var{A}, @var{B})
+## @documentencoding UTF-8
+## @defmethod {@@infsup} interior (@var{A}, @var{B})
 ## 
 ## Evaluate interior comparison on intervals.
 ##
@@ -26,7 +26,7 @@
 ## Evaluated on interval matrices, this functions is applied element-wise.
 ##
 ## @seealso{@@infsup/eq, @@infsup/subset, @@infsup/disjoint}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
