@@ -15,7 +15,8 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} {} @var{A} <= @var{B}
+## @defop Method {@@infsup} le (@var{A}, @var{B})
+## @defopx Operator {@@infsup} {@var{A} <= @var{B}}
 ## 
 ## Compare intervals @var{A} and @var{B} for weakly less.
 ##
@@ -26,7 +27,7 @@
 ## Evaluated on interval matrices, this functions is applied element-wise.
 ##
 ## @seealso{@@infsup/eq, @@infsup/lt, @@infsup/ge, @@infsup/subset, @@infsup/interior, @@infsup/disjoint}
-## @end deftypefn
+## @end defop
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
