@@ -15,7 +15,8 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} {} @var{X} - @var{Y}
+## @defop Method {@@infsup} minus (@var{X}, @var{Y})
+## @defopx Operator {@@infsup} {@var{X} - @var{Y}}
 ## 
 ## Subtract all numbers of interval @var{Y} from all numbers of @var{X}.
 ##
@@ -26,11 +27,11 @@
 ## x = infsup (2, 3);
 ## y = infsup (1, 2);
 ## x - y
-##   @result{} [0, 2]
+##   @result{} ans = [0, 2]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/plus}
-## @end deftypefn
+## @end defop
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
