@@ -15,13 +15,13 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} prepad (@var{X}, @var{L})
-## @deftypefnx {Function File} {} prepad (@var{X}, @var{L}, @var{C})
-## @deftypefnx {Function File} {} prepad (@var{X}, @var{L}, @var{C}, @var{DIM})
+## @defmethod {@@infsup} prepad (@var{X}, @var{L})
+## @defmethodx {@@infsup} prepad (@var{X}, @var{L}, @var{C})
+## @defmethodx {@@infsup} prepad (@var{X}, @var{L}, @var{C}, @var{DIM})
 ##
 ## Prepend the scalar interval value @var{C} to the interval vector @var{X}
-## until it is of length @var{L}.  If @var{C} is not given, an empty interval
-## is used.
+## until it is of length @var{L}.  If @var{C} is not given, a value of 0 is
+## used.
 ##
 ## If @code{length (@var{X}) > L}, elements from the beginning of @var{X} are
 ## removed until an interval vector of length @var{L} is obtained.
@@ -39,7 +39,7 @@
 ## @end group
 ## @end example
 ## @seealso{@@infsup/reshape, @@infsup/cat, @@infsup/postpad, @@infsup/resize}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
@@ -53,7 +53,7 @@ if (nargin < 2 || nargin > 4)
 endif
 
 if (nargin < 3)
-    c = infsup ();
+    c = infsup (0);
 elseif (not (isa (c, "infsup")))
     c = infsup (c);
 endif
