@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} psi (@var{X})
+## @defmethod {@@infsup} psi (@var{X})
 ## 
 ## Compute the digamma function, also known as the psi function.
 ##
@@ -41,10 +41,10 @@
 ## @example
 ## @group
 ## psi (infsup (1))
-##   @result{} ans ⊂ [-0.5772156649015329, -0.5772156649015327]
+##   @result{} ans ⊂ [-0.57722, -0.57721]
 ## @end group
 ## @end example
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
