@@ -15,8 +15,8 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} sum (@var{X})
-## @deftypefnx {Function File} {} sum (@var{X}, @var{DIM})
+## @defmethod {@@infsup} sum (@var{X})
+## @defmethodx {@@infsup} sum (@var{X}, @var{DIM})
 ## 
 ## Sum of elements along dimension @var{DIM}.  If @var{DIM} is omitted, it
 ## defaults to the first non-singleton dimension.
@@ -31,8 +31,8 @@
 ##   @result{} ans ⊂ [0, 2.2205e-16]
 ## @end group
 ## @end example
-## @seealso{@@infsup/plus}
-## @end deftypefn
+## @seealso{@@infsup/plus, @@infsup/prod}
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
@@ -53,17 +53,23 @@ if (nargin < 2)
     endif
 endif
 
+## Short-circuit
+if (size (x.inf, dim) == 1)
+    result = x;
+    return
+endif
+
 if (dim == 1)
-    resultsize = [1, size(x.inf, 2)];
+    resultsize = [1, max(1, size (x.inf, 2))];
 elseif (dim == 2)
-    resultsize = [size(x.inf, 1), 1];
+    resultsize = [max(1, size (x.inf, 1)), 1];
 else
     error ("interval:InvalidOperand", "sum: DIM must be a valid dimension")
 endif
 
 l = u = zeros (resultsize);
 
-for n = 1 : numel (l)
+for n = 1 : size (x.inf, 3 - dim)
     idx.type = "()";
     idx.subs = cell (1, 2);
     idx.subs {dim} = ":";
@@ -81,8 +87,8 @@ for n = 1 : numel (l)
         l (n) = inf;
         u (n) = -inf;
     else
-        l (n) = mpfr_vector_sum_d (-inf, x.inf);
-        u (n) = mpfr_vector_sum_d (+inf, x.sup);
+        l (n) = mpfr_vector_sum_d (-inf, vector.x.inf);
+        u (n) = mpfr_vector_sum_d (+inf, vector.x.sup);
     endif
 endfor
 
@@ -92,3 +98,4 @@ endfunction
 
 %!test "from the documentation string";
 %! assert (sum ([infsup(1), pow2(-1074), -1]) == infsup (pow2 (-1074)));
+%!assert (sum (infsup ([])) == 0);
