@@ -15,7 +15,8 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} {} @var{X} .* @var{Y}
+## @defop Method {@@infsup} times (@var{X}, @var{Y})
+## @defopx Operator {@@infsup} {@var{X} .* @var{Y}}
 ## 
 ## Multiply all numbers of interval @var{X} by all numbers of @var{Y}.
 ##
@@ -26,11 +27,11 @@
 ## x = infsup (2, 3);
 ## y = infsup (1, 2);
 ## x .* y
-##   @result{} [2, 6]
+##   @result{} ans = [2, 6]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/rdivide}
-## @end deftypefn
+## @end defop
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
