@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} acos (@var{X})
+## @defmethod {@@infsupdec} acos (@var{X})
 ## 
 ## Compute the inverse cosine in radians (arccosine).
 ##
@@ -24,11 +24,11 @@
 ## @example
 ## @group
 ## acos (infsupdec (.5))
-##   @result{} ans ⊂ [1.0471975511965976, 1.0471975511965979]_com
+##   @result{} ans ⊂ [1.0471, 1.0472]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/cos}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
