@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} acosh (@var{X})
+## @defmethod {@@infsupdec} acosh (@var{X})
 ## 
 ## Compute the inverse hyperbolic cosine.
 ##
@@ -24,11 +24,11 @@
 ## @example
 ## @group
 ## acosh (infsupdec (2))
-##   @result{} ans ⊂ [1.3169578969248165, 1.3169578969248168]_com
+##   @result{} ans ⊂ [1.3169, 1.317]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/cosh}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
