@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} exp (@var{X})
+## @defmethod {@@infsupdec} exp (@var{X})
 ## 
 ## Compute the exponential function.
 ##
@@ -24,11 +24,11 @@
 ## @example
 ## @group
 ## exp (infsupdec (1))
-##   @result{} ans ⊂ [2.718281828459045, 2.7182818284590456]_com
+##   @result{} ans ⊂ [2.7182, 2.7183]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/log, @@infsupdec/pow}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
