@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} fix (@var{X})
+## @defmethod {@@infsupdec} fix (@var{X})
 ## 
 ## Truncate fractional portion of each number in interval @var{X}.  This is
 ## equivalent to rounding towards zero.
@@ -25,13 +25,13 @@
 ## @example
 ## @group
 ## fix (infsupdec (2.5, 3.5))
-##   @result{} [2, 3]_def
+##   @result{} ans = [2, 3]_def
 ## fix (infsupdec (-0.5, 5))
-##   @result{} [0, 5]_def
+##   @result{} ans = [0, 5]_def
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/floor, @@infsupdec/ceil, @@infsupdec/round, @@infsupdec/roundb}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
