@@ -14,8 +14,9 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
-## @deftypefn {Function File} {} {} @var{A} <= @var{B}
+## @documentencoding UTF-8
+## @defop Method {@@infsupdec} le (@var{A}, @var{B})
+## @defopx Operator {@@infsupdec} {@var{A} <= @var{B}}
 ## 
 ## Compare intervals @var{A} and @var{B} for weakly less.
 ##
@@ -26,7 +27,7 @@
 ## Evaluated on interval matrices, this functions is applied element-wise.
 ##
 ## @seealso{@@infsupdec/eq, @@infsupdec/lt, @@infsupdec/ge, @@infsupdec/subset, @@infsupdec/interior, @@infsupdec/disjoint}
-## @end deftypefn
+## @end defop
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
