@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} log (@var{X})
+## @defmethod {@@infsupdec} log (@var{X})
 ## 
 ## Compute the natural logarithm.
 ##
@@ -26,11 +26,11 @@
 ## @example
 ## @group
 ## log (infsupdec (2))
-##   @result{} ans ⊂ [0.6931471805599452, 0.6931471805599454]_com
+##   @result{} ans ⊂ [0.69314, 0.69315]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/exp, @@infsupdec/log2, @@infsupdec/log10}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
