@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} log2 (@var{X})
+## @defmethod {@@infsupdec} log2 (@var{X})
 ## 
 ## Compute the binary (base-2) logarithm.
 ##
@@ -26,11 +26,11 @@
 ## @example
 ## @group
 ## log2 (infsupdec (2))
-##   @result{} [1]_com
+##   @result{} ans = [1]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/pow2, @@infsupdec/log, @@infsupdec/log10}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
