@@ -15,7 +15,8 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} {} @var{X} \ @var{Y}
+## @defop Method {@@infsupdec} mldivide (@var{X}, @var{Y})
+## @defopx Operator {@@infsupdec} {@var{X} \ @var{Y}}
 ## 
 ## Return the interval matrix left division of @var{X} and @var{Y}.
 ##
@@ -24,14 +25,13 @@
 ## @example
 ## @group
 ## infsupdec ([1, 0; 0, 2]) \ [2, 0; 0, 4]
-##   @result{} 2×2 interval matrix
-##
+##   @result{} ans = 2×2 interval matrix
 ##      [2]_trv   [0]_trv
 ##      [0]_trv   [2]_trv
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/mtimes}
-## @end deftypefn
+## @end defop
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
