@@ -15,10 +15,10 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {@var{X} =} mulrev (@var{B}, @var{C}, @var{X})
-## @deftypefnx {Function File} {@var{X} =} mulrev (@var{B}, @var{C})
-## @deftypefnx {Function File} {[@var{U}, @var{V}] =} mulrev (@var{B}, @var{C})
-## @deftypefnx {Function File} {[@var{U}, @var{V}] =} mulrev (@var{B}, @var{C}, @var{X})
+## @deftypemethod {@@infsupdec} {@var{X} =} mulrev (@var{B}, @var{C}, @var{X})
+## @deftypemethodx {@@infsupdec} {@var{X} =} mulrev (@var{B}, @var{C})
+## @deftypemethodx {@@infsupdec} {[@var{U}, @var{V}] =} mulrev (@var{B}, @var{C})
+## @deftypemethodx {@@infsupdec} {[@var{U}, @var{V}] =} mulrev (@var{B}, @var{C}, @var{X})
 ## 
 ## Compute the reverse multiplication function or the two-output division.
 ##
@@ -51,7 +51,7 @@
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/times}
-## @end deftypefn
+## @end deftypemethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
@@ -104,7 +104,7 @@ endif
 
 endfunction
 
-%!test "IEEE 1788 mulRevToPair examples";
+%!test "IEEE Std 1788-2015 mulRevToPair examples";
 %!  [u, v] = mulrev (infsupdec (0), infsupdec (1, 2));
 %!  assert (isempty (u) & isempty (v));
 %!  [u, v] = mulrev (infsupdec (0), infsupdec (0, 1));
