@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} pow10 (@var{X})
+## @defmethod {@@infsupdec} pow10 (@var{X})
 ## 
 ## Compute @code{10^x} for all numbers in @var{X}.
 ##
@@ -24,11 +24,11 @@
 ## @example
 ## @group
 ## pow10 (infsupdec (5))
-##   @result{} ans = [100000]_com
+##   @result{} ans = [1e+05]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/log10, @@infsupdec/pow, @@infsupdec/pow2, @@infsupdec/exp}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
