@@ -15,8 +15,8 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} sum (@var{X})
-## @deftypefnx {Function File} {} sum (@var{X}, @var{DIM})
+## @defmethod {@@infsupdec} sum (@var{X})
+## @defmethodx {@@infsupdec} sum (@var{X}, @var{DIM})
 ## 
 ## Sum of elements along dimension @var{DIM}.  If @var{DIM} is omitted, it
 ## defaults to the first non-singleton dimension.
@@ -26,13 +26,13 @@
 ## @example
 ## @group
 ## sum ([infsupdec(1), pow2(-1074), -1])
-##   @result{} ans ⊂ [4.940656458412465e-324, 4.940656458412466e-324]_com
+##   @result{} ans ⊂ [4.9406e-324, 4.9407e-324]_com
 ## infsupdec (1) + pow2 (-1074) - 1
-##   @result{} ans ⊂ [0, 2.220446049250314e-16]_com
+##   @result{} ans ⊂ [0, 2.2205e-16]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/plus}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
@@ -53,16 +53,10 @@ if (nargin < 2)
     endif
 endif
 
-if (dim == 1)
-    resultsize = [1, size(x.dec, 2)];
-elseif (dim == 2)
-    resultsize = [size(x.dec, 1), 1];
-else
-    error ("interval:InvalidOperand", "sum: DIM must be a valid dimension")
-endif
-
 result = newdec (sum (intervalpart (x), dim));
-result.dec = min (result.dec, min (x.dec, [], dim));
+if (not (isempty (x.dec)))
+    result.dec = min (result.dec, min (x.dec, [], dim));
+endif
 
 endfunction
 
