@@ -15,7 +15,7 @@
 
 ## -*- texinfo -*-
 ## @documentencoding UTF-8
-## @deftypefn {Function File} {} tan (@var{X})
+## @defmethod {@@infsupdec} tan (@var{X})
 ## 
 ## Compute the tangent in radians.
 ##
@@ -24,11 +24,11 @@
 ## @example
 ## @group
 ## tan (infsupdec (1))
-##   @result{} ans ⊂ [1.557407724654902, 1.5574077246549023]_com
+##   @result{} ans ⊂ [1.5574, 1.5575]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/atan, @@infsupdec/tanh}
-## @end deftypefn
+## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
