@@ -63,27 +63,33 @@ void evaluate (
   mpfr_init2 (mp1, BINARY64_PRECISION);
   mpfr_init2 (mp2, BINARY64_PRECISION);
   
-  bool scalar1 = arg1.numel () == 1;
-  bool scalar2 = arg2.numel () == 1;
+  // arg1 shall contain the result and must be resized
+  if (arg1.rows () == 1 && arg2.rows () != 1)
+    arg1 = arg1.index (idx_vector (ColumnVector (arg2.rows (), 1.0)), 
+                       idx_vector::colon);
+  if (arg1.columns () == 1 && arg2.columns () != 1)
+    arg1 = arg1.index (idx_vector::colon,
+                       idx_vector (RowVector (arg2.columns (), 1.0)));
   
-  if (scalar1 && ! scalar2)
-    {
-      // arg1 shall contain the result and must be resized
-      arg1 = Matrix (arg2.dims (), arg1.elem (0));
-      scalar1 = false;
-    }
+  const octave_idx_type n = arg1.rows ();
+  const octave_idx_type m = arg1.columns ();
+  const bool broadcast_r = n != 1 && arg2.rows () == 1;
+  const bool broadcast_c = m != 1 && arg2.columns () == 1;
   
-  const octave_idx_type n = std::max (arg1.numel (), arg2.numel ());
   for (octave_idx_type i = 0; i < n; i ++)
-    {
-      mpfr_set_d (mp1, arg1.elem (i), MPFR_RNDZ);
-      mpfr_set_d (mp2,
-                  (scalar2) ? arg2.elem (0) // broadcast
-                            : arg2.elem (i),
-                  MPFR_RNDZ);
-      (*f) (mp1, mp1, mp2, rnd);
-      arg1.elem (i) = mpfr_get_d (mp1, rnd);
-    }
+    for (octave_idx_type j = 0; j < m; j ++)
+      {
+        mpfr_set_d (mp1, arg1.elem (i, j), MPFR_RNDZ);
+        mpfr_set_d (mp2,
+                    (broadcast_r)
+                      ? ((broadcast_c) ? arg2.elem (0, 0)
+                                       : arg2.elem (0, j))
+                      : ((broadcast_c) ? arg2.elem (i, 0)
+                                       : arg2.elem (i, j))
+                    , MPFR_RNDZ);
+        (*f) (mp1, mp1, mp2, rnd);
+        arg1.elem (i, j) = mpfr_get_d (mp1, rnd);
+      }
   
   mpfr_clear (mp1);
   mpfr_clear (mp2);
@@ -166,54 +172,54 @@ void nthroot (
 DEFUN_DLD (mpfr_function_d, args, nargout, 
   "-*- texinfo -*-\n"
   "@documentencoding UTF-8\n"
-  "@deftypefn  {Loadable Function} {} mpfr_function_d ('acos', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('acosh', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('asin', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('asinh', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('atan', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('atan2', @var{R}, @var{Y}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('atanh', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('cbrt', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('cos', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('cosh', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('cot', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('coth', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('csc', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('csch', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('dilog', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('ei', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('erf', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('erfc', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('exp', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('expm1', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('fma', @var{R}, @var{X}, @var{Y}, @var{Z})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('gamma', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('gammaln', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('hypot', @var{R}, @var{X}, @var{Y})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('log', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('log2', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('log10', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('log1p', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('minus', @var{R}, @var{X}, @var{Y})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('nthroot', @var{R}, @var{X}, @var{N})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('plus', @var{R}, @var{X}, @var{Y})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('pow', @var{R}, @var{X}, @var{Y})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('pow2', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('pow10', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('psi', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('rdivide', @var{R}, @var{X}, @var{Y})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('realsqrt', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('rsqrt', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sec', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sech', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sin', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sinh', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sinh', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sinh', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('sqr', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('tan', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('tanh', @var{R}, @var{X})\n"
-  "@deftypefnx {Loadable Function} {} mpfr_function_d ('times', @var{R}, @var{X}, @var{Y})\n"
+  "@defun mpfr_function_d ('acos', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('acosh', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('asin', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('asinh', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('atan', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('atan2', @var{R}, @var{Y}, @var{X})\n"
+  "@defunx mpfr_function_d ('atanh', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('cbrt', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('cos', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('cosh', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('cot', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('coth', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('csc', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('csch', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('dilog', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('ei', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('erf', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('erfc', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('exp', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('expm1', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('fma', @var{R}, @var{X}, @var{Y}, @var{Z})\n"
+  "@defunx mpfr_function_d ('gamma', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('gammaln', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('hypot', @var{R}, @var{X}, @var{Y})\n"
+  "@defunx mpfr_function_d ('log', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('log2', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('log10', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('log1p', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('minus', @var{R}, @var{X}, @var{Y})\n"
+  "@defunx mpfr_function_d ('nthroot', @var{R}, @var{X}, @var{N})\n"
+  "@defunx mpfr_function_d ('plus', @var{R}, @var{X}, @var{Y})\n"
+  "@defunx mpfr_function_d ('pow', @var{R}, @var{X}, @var{Y})\n"
+  "@defunx mpfr_function_d ('pow2', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('pow10', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('psi', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('rdivide', @var{R}, @var{X}, @var{Y})\n"
+  "@defunx mpfr_function_d ('realsqrt', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('rsqrt', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('sec', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('sech', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('sin', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('sinh', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('sinh', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('sinh', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('sqr', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('tan', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('tanh', @var{R}, @var{X})\n"
+  "@defunx mpfr_function_d ('times', @var{R}, @var{X}, @var{Y})\n"
   "\n"
   "Evaluate a function in binary64 with correctly rounded result."
   "\n\n"
@@ -239,7 +245,7 @@ DEFUN_DLD (mpfr_function_d, args, nargout,
   "@end group\n"
   "@end example\n"
   "@seealso{fesetround}\n"
-  "@end deftypefn"
+  "@end defun"
   )
 {
   // Check call syntax
@@ -259,8 +265,11 @@ DEFUN_DLD (mpfr_function_d, args, nargout,
   if (nargin >= 4)
     {
       arg2                   = args (3).matrix_value ();
-      if (arg1.numel () != 1 && arg2.numel () != 1 &&
-          arg1.numel () != arg2.numel ())
+      if (arg1.rows () != 1 && arg2.rows () != 1 &&
+          arg1.rows () != arg2.rows ())
+        error ("mpfr_function_d: Matrix dimensions must agree!");
+      if (arg1.columns () != 1 && arg2.columns () != 1 &&
+          arg1.columns () != arg2.columns ())
         error ("mpfr_function_d: Matrix dimensions must agree!");
     }
   if (nargin >= 5)
