@@ -22,7 +22,7 @@
 DEFUN_DLD (mpfr_vector_sum_d, args, nargout, 
   "-*- texinfo -*-\n"
   "@documentencoding UTF-8\n"
-  "@deftypefn  {Loadable Function} {[@var{S}, @var{E}] =} mpfr_vector_sum_d (@var{R}, @var{X})\n"
+  "@deftypefun {[@var{S}, @var{E}] =} mpfr_vector_sum_d (@var{R}, @var{X})\n"
   "\n"
   "Compute the sum @var{S} of all numbers in a binary64 vector @var{X} with "
   "correctly rounded result."
@@ -53,7 +53,7 @@ DEFUN_DLD (mpfr_vector_sum_d, args, nargout,
   "@end group\n"
   "@end example\n"
   "@seealso{sum}\n"
-  "@end deftypefn"
+  "@end deftypefun"
   )
 {
   // Check call syntax
